==> wmhpicker-0.0.4.tar.gz: lib/wmhpicker.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';

typedef List<Widget> CreateWidgetList();

class WMHPickerView extends Dialog {
  List<Map> pickerData;
  List<String> selectedArr = [];
  final callBack;
  bool showPicker;
  Color cancelBtnColor;
  Color confirmBtnColor;
  Color pickerBackgroundColor;
  Color pickerTextColor;
  double textSize;
  double pickerHeight;

  bool isDatePicker;
  int maxYear;
  int minYear;

  WMHPickerView({Key key,
    this.pickerData,
    this.callBack,
    this.showPicker,
    this.cancelBtnColor,
    this.confirmBtnColor,
    this.pickerBackgroundColor,
    this.pickerTextColor,
    this.textSize,
    this.pickerHeight,
    this.isDatePicker,
    this.maxYear,
    this.minYear,
  }) : super(key : key);

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return wmhPickerStateful(pickerData: this.pickerData,
      callBack: this.callBack,
    showPicker: this.showPicker,
    cancelBtnColor: this.cancelBtnColor,
    confirmBtnColor: this.confirmBtnColor,
    pickerBackgroundColor: this.pickerBackgroundColor,
    pickerTextColor: this.pickerTextColor,
    textSize: this.textSize,
    pickerHeight: this.pickerHeight,
    isDatePicker: this.isDatePicker,
    maxYear: this.maxYear,
    minYear: this.minYear,);
  }
}

class wmhPickerStateful extends StatefulWidget {
  List<Map> pickerData;
  List<String> selectedArr = [];
  final callBack;
  bool showPicker;
  Color cancelBtnColor;
  Color confirmBtnColor;
  Color pickerBackgroundColor;
  Color pickerTextColor;
  double textSize;
  double pickerHeight;

  bool isDatePicker;
  int maxYear;
  int minYear;

  wmhPickerStateful({Key key,
    this.pickerData,
    this.callBack,
    this.showPicker,
    this.cancelBtnColor,
    this.confirmBtnColor,
    this.pickerBackgroundColor,
    this.pickerTextColor,
    this.textSize,
    this.pickerHeight,
    this.isDatePicker,
    this.maxYear,
    this.minYear,
  }) : super(key : key);

  wmhPickerState createState() => wmhPickerState(
    this.pickerData,
    this.callBack,
    this.showPicker,
    this.cancelBtnColor,
    this.confirmBtnColor,
    this.pickerBackgroundColor,
    this.pickerTextColor,
    this.textSize,
    this.pickerHeight,
    this.isDatePicker,
    this.maxYear,
    this.minYear,
  );
}

class wmhPickerState extends State<wmhPickerStateful> {
  List<Map> pickerData;
  List<String> selectedArr = [];
  var callBack;
  bool showPicker;
  Color cancelBtnColor;
  Color confirmBtnColor;
  Color pickerBackgroundColor;
  Color pickerTextColor;
  double textSize;
  double pickerHeight;
  bool isDatePicker;
  int maxYear;
  int minYear;

  List yearArr = [];
  List monthArr = [];
  int lastYearIndex = 0;
  int lastMonthIndex = 0;
  int lastDayIndex = 0;

  FixedExtentScrollController controller = new FixedExtentScrollController(initialItem: 0);

  wmhPickerState(
      this.pickerData,
      this.callBack,
      this.showPicker,
      this.cancelBtnColor,
      this.confirmBtnColor,
      this.pickerBackgroundColor,
      this.pickerTextColor,
      this.textSize,
      this.pickerHeight,
      this.isDatePicker,
      this.maxYear,
      this.minYear,
      );

  @override
  void dispose() {
    // TODO: implement dispose
    controller.dispose();
    super.dispose();
  }

  @override
  void initState() {
    if (this.isDatePicker == true) {
      var yearArr = [];
      for (var i = minYear; i <= maxYear; i++) {
        yearArr.add(i);
      }
      this.yearArr = yearArr;
      var monthArr = [];
      for (var i = 1; i <= 12; i++) {
        monthArr.add(i);
      }
      this.monthArr = monthArr;
      var dayArr = [];
      for (var i = 1; i <= getDaysNum(yearArr[0], monthArr[0]); i++) {
        dayArr.add(i);
      }

      this.pickerData = [
        {'subDatas' : yearArr},
        {'subDatas' : monthArr},
        {'subDatas' : dayArr},
      ];
    }
    super.initState();
  }

  /*根据年份月份获取当前月有多少天*/
  int getDaysNum(int y, int m) {
    if (m == 1 || m == 3 || m == 5 || m == 7 || m == 8 || m == 10 || m == 12) {
      return 31;
    } else if (m == 2) {
      if (((y % 4 == 0) && (y % 100 != 0)) || (y % 400 == 0)) {
        //闰年 2月29
        return 29;
      } else {
        //平年 2月28
        return 28;
      }
    } else {
      return 30;
    }
  }

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return GestureDetector(
      onTap: () {
        Navigator.pop(context);
      },
      child: Material(
        type: MaterialType.transparency,
        child: Container(
          width: MediaQuery.of(context).size.width,
          height: MediaQuery.of(context).size.height,
          alignment: Alignment.bottomCenter,
          child: Container(
            width: MediaQuery.of(context).size.width,
            height: this.pickerHeight,
            color: this.pickerBackgroundColor,
            child: Container(
              child: Column(
                children: <Widget>[
                  _buttonVIew(context),
                  Row(
                    children: _getColumnPicker(context),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }

  _getColumnPicker(BuildContext context) {
    List<Widget> pickerColumnArr = [];
    for (var i = 0; i < this.pickerData.length; i++) {
      Map model = this.pickerData[i];
      if (selectedArr.length == this.pickerData.length) {
        selectedArr = [];
      }
      if (this.isDatePicker == true) {
        if (i == 0) {
          selectedArr.add(pickerData[0]['subDatas'][lastYearIndex].toString());
        }else if (i == 1) {
          selectedArr.add(pickerData[1]['subDatas'][lastMonthIndex].toString());
        }else if (i == 2) {
          selectedArr.add(pickerData[2]['subDatas'][lastDayIndex].toString());
        }else{
          print('hehe');
        }
      }else{
        selectedArr.add(model['subDatas'][0].toString());
      }
      pickerColumnArr.add(
        _buildBottomPicker(
            CupertinoPicker(
              scrollController: i == 2 ? controller : new FixedExtentScrollController(initialItem: 0),
              itemExtent: 40.0,
              backgroundColor: this.pickerBackgroundColor,
              onSelectedItemChanged: (int index) {
                if (this.isDatePicker == true) {
                  if (i == 0) {
                    lastYearIndex = index;
                  }else if (i == 1) {
                    lastMonthIndex = index;
                  }else{
                    lastDayIndex = index;
                  }
                  print(pickerData[0]['subDatas'][lastYearIndex].toString() + pickerData[1]['subDatas'][lastMonthIndex].toString());
                  _changeDays(pickerData[0]['subDatas'][lastYearIndex], pickerData[1]['subDatas'][lastMonthIndex], 2, i);
                  selectedArr[0] = pickerData[0]['subDatas'][lastYearIndex].toString();
                  selectedArr[1] = pickerData[1]['subDatas'][lastMonthIndex].toString();
                  selectedArr[2] = pickerData[2]['subDatas'][lastDayIndex].toString();
                  print(selectedArr.toString());
                }else{
                  selectedArr[i] = model['subDatas'][index].toString();
                }
              },
              children: List<Widget>.generate(model['subDatas'].length, (int index) {
                return Center(
                  child: _showText(i, model, index),
                );
              }),
            ),context
        ),
      );
    }
    return pickerColumnArr;
  }
  
  _showText(int column, Map model, int index) {
    if (this.isDatePicker == true) {
      if (column == 0) {
        return Text(model['subDatas'][index].toString() + '年');
      }else if(column == 1) {
        return Text(model['subDatas'][index].toString() + '月');
      }else {
        return Text(model['subDatas'][index].toString() + '日');
      }
    }else {
      return Text(model['subDatas'][index].toString());
    }
  }

  _changeDays(int year, int month, int dayColumn, int column) {
    setState(() {
      var dayArr = [];
      for (var i = 1; i <= getDaysNum(year, month); i++) {
        dayArr.add(i);
      }
      this.pickerData[dayColumn] = {'subDatas' : dayArr};
      if (column != 2) {
        controller.jumpTo(0);
        lastDayIndex = 0;
      }
    });
  }

  Widget _buttonVIew(BuildContext context) {
    return new Container(
      width: MediaQuery.of(context).size.width,
      height: 50.0,
      color: this.pickerBackgroundColor,
      child: new Row(
        children: <Widget>[
          Container(
            child: FlatButton(
              onPressed: () {
                print('点击取消');
                Navigator.pop(context);
              },
              child: new Text(
                '取消',
              ),
            ),
          ),
          Container (
            child: FlatButton(
              onPressed: () {
                print('点击完成' + this.selectedArr.toString());
                Navigator.pop(context);
                callBack(this.selectedArr);
              },
              child: new Text(
                '完成',
              ),
            ),
          ),
        ],
        mainAxisSize: MainAxisSize.max,
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
      ),
    );
  }

  Widget _buildBottomPicker(Widget picker, BuildContext context) {
    return Container(
      height: this.pickerHeight - 70.0,
      width: MediaQuery.of(context).size.width / this.pickerData.length,
      color: this.pickerBackgroundColor,
      child: DefaultTextStyle(
        style: TextStyle(
          color: this.pickerTextColor,
          fontSize: this.textSize,
        ),
        child: GestureDetector(
          key: Key('picker'),
          onTap: (){},
          child: SafeArea(
            top: false,
            child: picker,
          ),
        ),
      ),
    );
  }
}

class Wmhpicker {
  static const MethodChannel _channel =
      const MethodChannel('wmhpicker');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
}

==> wmhpicker-0.0.5.tar.gz: lib/wmhpicker.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';

typedef List<Widget> CreateWidgetList();

class WMHPickerView extends Dialog {
  List<Map> pickerData;
  List<String> selectedArr = [];
  final callBack;
  bool showPicker;
  Color cancelBtnColor;
  Color confirmBtnColor;
  Color pickerBackgroundColor;
  Color pickerTextColor;
  double textSize;
  double pickerHeight;

  bool isDatePicker;
  int maxYear;
  int minYear;

  WMHPickerView({Key key,
    this.pickerData,
    this.callBack,
    this.showPicker,
    this.cancelBtnColor,
    this.confirmBtnColor,
    this.pickerBackgroundColor,
    this.pickerTextColor,
    this.textSize,
    this.pickerHeight,
    this.isDatePicker,
    this.maxYear,
    this.minYear,
  }) : super(key : key);

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return wmhPickerStateful(pickerData: this.pickerData,
      callBack: this.callBack,
    showPicker: this.showPicker,
    cancelBtnColor: this.cancelBtnColor,
    confirmBtnColor: this.confirmBtnColor,
    pickerBackgroundColor: this.pickerBackgroundColor,
    pickerTextColor: this.pickerTextColor,
    textSize: this.textSize,
    pickerHeight: this.pickerHeight,
    isDatePicker: this.isDatePicker,
    maxYear: this.maxYear,
    minYear: this.minYear,);
  }
}

class wmhPickerStateful extends StatefulWidget {
  List<Map> pickerData;
  List<String> selectedArr = [];
  final callBack;
  bool showPicker;
  Color cancelBtnColor;
  Color confirmBtnColor;
  Color pickerBackgroundColor;
  Color pickerTextColor;
  double textSize;
  double pickerHeight;

  bool isDatePicker;
  int maxYear;
  int minYear;

  wmhPickerStateful({Key key,
    this.pickerData,
    this.callBack,
    this.showPicker,
    this.cancelBtnColor,
    this.confirmBtnColor,
    this.pickerBackgroundColor,
    this.pickerTextColor,
    this.textSize,
    this.pickerHeight,
    this.isDatePicker,
    this.maxYear,
    this.minYear,
  }) : super(key : key);

  wmhPickerState createState() => wmhPickerState(
    this.pickerData,
    this.callBack,
    this.showPicker,
    this.cancelBtnColor,
    this.confirmBtnColor,
    this.pickerBackgroundColor,
    this.pickerTextColor,
    this.textSize,
    this.pickerHeight,
    this.isDatePicker,
    this.maxYear,
    this.minYear,
  );
}

class wmhPickerState extends State<wmhPickerStateful> {
  List<Map> pickerData;
  List<String> selectedArr = [];
  var callBack;
  bool showPicker;
  Color cancelBtnColor;
  Color confirmBtnColor;
  Color pickerBackgroundColor;
  Color pickerTextColor;
  double textSize;
  double pickerHeight;
  bool isDatePicker;
  int maxYear;
  int minYear;

  List yearArr = [];
  List monthArr = [];
  int lastYearIndex = 0;
  int lastMonthIndex = 0;
  int lastDayIndex = 0;

  FixedExtentScrollController controller = new FixedExtentScrollController(initialItem: 0);

  wmhPickerState(
      this.pickerData,
      this.callBack,
      this.showPicker,
      this.cancelBtnColor,
      this.confirmBtnColor,
      this.pickerBackgroundColor,
      this.pickerTextColor,
      this.textSize,
      this.pickerHeight,
      this.isDatePicker,
      this.maxYear,
      this.minYear,
      );

  @override
  void dispose() {
    // TODO: implement dispose
    controller.dispose();
    super.dispose();
  }

  @override
  void initState() {
    if (this.isDatePicker == true) {
      var yearArr = [];
      for (var i = maxYear; i >= minYear; i--) {
        yearArr.add(i);
      }
      this.yearArr = yearArr;
      var monthArr = [];
      for (var i = 1; i <= 12; i++) {
        monthArr.add(i);
      }
      this.monthArr = monthArr;
      var dayArr = [];
      for (var i = 1; i <= getDaysNum(yearArr[0], monthArr[0]); i++) {
        dayArr.add(i);
      }

      this.pickerData = [
        {'subDatas' : yearArr},
        {'subDatas' : monthArr},
        {'subDatas' : dayArr},
      ];
    }
    super.initState();
  }

  /*根据年份月份获取当前月有多少天*/
  int getDaysNum(int y, int m) {
    if (m == 1 || m == 3 || m == 5 || m == 7 || m == 8 || m == 10 || m == 12) {
      return 31;
    } else if (m == 2) {
      if (((y % 4 == 0) && (y % 100 != 0)) || (y % 400 == 0)) {
        //闰年 2月29
        return 29;
      } else {
        //平年 2月28
        return 28;
      }
    } else {
      return 30;
    }
  }

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return GestureDetector(
      onTap: () {
        Navigator.pop(context);
      },
      child: Material(
        type: MaterialType.transparency,
        child: Container(
          width: MediaQuery.of(context).size.width,
          height: MediaQuery.of(context).size.height,
          alignment: Alignment.bottomCenter,
          child: Container(
            width: MediaQuery.of(context).size.width,
            height: this.pickerHeight,
            color: this.pickerBackgroundColor,
            child: Container(
              child: Column(
                children: <Widget>[
                  _buttonVIew(context),
                  Row(
                    children: _getColumnPicker(context),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }

  _getColumnPicker(BuildContext context) {
    List<Widget> pickerColumnArr = [];
    for (var i = 0; i < this.pickerData.length; i++) {
      Map model = this.pickerData[i];
      if (selectedArr.length == this.pickerData.length) {
        selectedArr = [];
      }
      if (this.isDatePicker == true) {
        if (i == 0) {
          selectedArr.add(pickerData[0]['subDatas'][lastYearIndex].toString());
        }else if (i == 1) {
          selectedArr.add(pickerData[1]['subDatas'][lastMonthIndex].toString());
        }else if (i == 2) {
          selectedArr.add(pickerData[2]['subDatas'][lastDayIndex].toString());
        }else{
          print('hehe');
        }
      }else{
        selectedArr.add(model['subDatas'][0].toString());
      }
      pickerColumnArr.add(
        _buildBottomPicker(
            CupertinoPicker(
              scrollController: i == 2 ? controller : new FixedExtentScrollController(initialItem: 0),
              itemExtent: 40.0,
              backgroundColor: this.pickerBackgroundColor,
              onSelectedItemChanged: (int index) {
                if (this.isDatePicker == true) {
                  if (i == 0) {
                    lastYearIndex = index;
                  }else if (i == 1) {
                    lastMonthIndex = index;
                  }else{
                    lastDayIndex = index;
                  }
                  print(pickerData[0]['subDatas'][lastYearIndex].toString() + pickerData[1]['subDatas'][lastMonthIndex].toString());
                  _changeDays(pickerData[0]['subDatas'][lastYearIndex], pickerData[1]['subDatas'][lastMonthIndex], 2, i);
                  selectedArr[0] = pickerData[0]['subDatas'][lastYearIndex].toString();
                  selectedArr[1] = pickerData[1]['subDatas'][lastMonthIndex].toString();
                  selectedArr[2] = pickerData[2]['subDatas'][lastDayIndex].toString();
                  print(selectedArr.toString());
                }else{
                  selectedArr[i] = model['subDatas'][index].toString();
                }
              },
              children: List<Widget>.generate(model['subDatas'].length, (int index) {
                return Center(
                  child: _showText(i, model, index)
                );
              }),
            ),context
        ),
      );
    }
    return pickerColumnArr;
  }
  
  _showText(int column, Map model, int index) {
    if (this.isDatePicker == true) {
      if (column == 0) {
        return Text(model['subDatas'][index].toString() + '年');
      }else if(column == 1) {
        return Text(model['subDatas'][index].toString() + '月');
      }else {
        return Text(model['subDatas'][index].toString() + '日');
      }
    }else {
      return Text(model['subDatas'][index].toString());
    }
  }

  _changeDays(int year, int month, int dayColumn, int column) {
    setState(() {
      var dayArr = [];
      for (var i = 1; i <= getDaysNum(year, month); i++) {
        dayArr.add(i);
      }
      this.pickerData[dayColumn] = {'subDatas' : dayArr};
      if (column != 2) {
        controller.jumpTo(0);
        lastDayIndex = 0;
      }
    });
  }

  Widget _buttonVIew(BuildContext context) {
    return new Container(
      width: MediaQuery.of(context).size.width,
      height: 50.0,
      color: this.pickerBackgroundColor,
      child: new Row(
        children: <Widget>[
          Container(
            child: FlatButton(
              onPressed: () {
                print('点击取消');
                Navigator.pop(context);
              },
              child: new Text(
                '取消',
              ),
            ),
          ),
          Container (
            child: FlatButton(
              onPressed: () {
                print('点击完成' + this.selectedArr.toString());
                Navigator.pop(context);
                callBack(this.selectedArr);
              },
              child: new Text(
                '完成',
              ),
            ),
          ),
        ],
        mainAxisSize: MainAxisSize.max,
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
      ),
    );
  }

  Widget _buildBottomPicker(Widget picker, BuildContext context) {
    return Container(
      height: this.pickerHeight - 70.0,
      width: MediaQuery.of(context).size.width / this.pickerData.length,
      color: this.pickerBackgroundColor,
      child: DefaultTextStyle(
        style: TextStyle(
          color: this.pickerTextColor,
          fontSize: this.textSize,
        ),
        child: GestureDetector(
          key: Key('picker'),
          onTap: (){},
          child: SafeArea(
            top: false,
            child: picker,
          ),
        ),
      ),
    );
  }
}

class Wmhpicker {
  static const MethodChannel _channel =
      const MethodChannel('wmhpicker');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
}
